%define major     21
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define minor	  %nil

Name:           djvulibre
Version:        3.5.28
%define subrel 1
Release:        %mkrel 5
Summary:        DjVu viewers, encoders and utilities
License:        GPLv2+
Group:          Publishing
URL:            https://djvu.sourceforge.net/
Source0:        https://download.sourceforge.net/djvu/%{name}-%{version}%{minor}.tar.gz
Patch0:         CVE-2021-3500.patch
Patch1:         CVE-2021-32490.patch
Patch2:         CVE-2021-32491.patch
Patch3:         CVE-2021-32492.patch
Patch4:         CVE-2021-32493.patch
Patch5:         CVE-2021-46310.patch
Patch6:         CVE-2021-46312.patch
Patch10:        0001-Use-grep-E-instead-of-deprecated-egrep.patch

BuildRequires:  gnome-mime-data
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(xt)
BuildRequires:  xdg-utils

%description
DjVu is a web-centric format and software platform for distributing
documents and images.  DjVu content downloads faster, displays and
renders faster, looks nicer on a screen, and consumes less client
resources than competing formats. DjVu was originally developed at AT&T
Labs-Research by Leon Bottou, Yann LeCun, Patrick Haffner, and many
others.  In March 2000, AT&T sold DjVu to LizardTech Inc. who now
distributes Windows/Mac plug-ins, and commercial encoders (mostly on
Windows)

In an effort to promote DjVu as a Web standard, the LizardTech
management was enlightened enough to release the reference
implementation of DjVu under the GNU GPL in October 2000.  DjVuLibre
(which means free DjVu), is an enhanced version of that code maintained
by the original inventors of DjVu. It is compatible with version 3.5 of
the LizardTech DjVu software suite.

DjVulibre-3.5 contains:
- a standalone DjVu viewer based on the Qt library.
- A browser plugin that works with most Unix browsers.
- A full-fledged wavelet-based compressor for pictures.
- A simple compressor for bitonal (black and white) scanned pages.
- A compressor for palettized images (a la GIF/PNG).
- A set of utilities to manipulate and assemble DjVu images and documents.
- A set of decoders to convert DjVu to a number of other formats.
- An up-to-date version of the C++ DjVu Reference Library.

%package -n %{libname}
Summary:        DjVulibre library
Group:          System/Libraries

%description -n %{libname}
Djvulibre shared libraries.

%package -n %{develname}
Summary:        DjVulibre development files
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       djvulibre-devel = %{version}-%{release}

%description -n %{develname}
DjVulibre development files.

%package browser-plugin
Summary:        DjVulibre browser plugin
Group:          Publishing
Requires:       %{name} = %{version}-%{release}

%description browser-plugin
A browser plugin that works with most Unix browsers.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure \
    --prefix=%{_prefix} \
    --enable-xmltools \
    --enable-threads \
    --enable-i18n \
    --enable-desktopfiles

%make_build

%install
%make_install

# we don't want these
find %{buildroot} -name "*.la" -delete

%files
%doc README COPYRIGHT COPYING INSTALL NEWS doc
%{_bindir}/any2djvu
%{_bindir}/bzz
%{_bindir}/c44
%{_bindir}/cjb2
%{_bindir}/cpaldjvu
%{_bindir}/csepdjvu
%{_bindir}/ddjvu
%{_bindir}/djvm
%{_bindir}/djvmcvt
%{_bindir}/djvudigital
%{_bindir}/djvudump
%{_bindir}/djvuextract
%{_bindir}/djvumake
%{_bindir}/djvups
%{_bindir}/djvused
%{_bindir}/djvuserve
%{_bindir}/djvutoxml
%{_bindir}/djvutxt
%{_bindir}/djvuxmlparser
%{_datadir}/djvu
%{_mandir}/man1/any2djvu.1*
%{_mandir}/man1/bzz.1*
%{_mandir}/man1/c44.1*
%{_mandir}/man1/cjb2.1*
%{_mandir}/man1/cpaldjvu.1*
%{_mandir}/man1/csepdjvu.1*
%{_mandir}/man1/ddjvu.1*
%{_mandir}/man1/djvm.1*
%{_mandir}/man1/djvmcvt.1*
%{_mandir}/man1/djvu.1*
%{_mandir}/man1/djvudigital.1*
%{_mandir}/man1/djvudump.1*
%{_mandir}/man1/djvuextract.1*
%{_mandir}/man1/djvumake.1*
%{_mandir}/man1/djvups.1*
%{_mandir}/man1/djvused.1*
%{_mandir}/man1/djvuserve.1*
%{_mandir}/man1/djvutoxml.1*
%{_mandir}/man1/djvutxt.1*
%{_mandir}/man1/djvuxml.1*
%{_mandir}/man1/djvuxmlparser.1*
%{_iconsdir}/hicolor/*/mimetypes/*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/*.so
%{_includedir}/libdjvu
%{_libdir}/pkgconfig/*.pc


%changelog
* Sat May 18 2024 daviddavid <daviddavid> 3.5.28-5.1.mga9
+ Revision: 2064698
- backport patches to fix CVE-2021-46310 and CVE-2021-46312 (mga#33221)

* Wed May 03 2023 daviddavid <daviddavid> 3.5.28-5.mga9
+ Revision: 1955720
- add patch to use `grep -E` instead of deprecated `egrep`

* Mon Dec 12 2022 ns80 <ns80> 3.5.28-4.mga9
+ Revision: 1921007
- rebuild for new libtiff

* Thu Mar 31 2022 umeabot <umeabot> 3.5.28-3.mga9
+ Revision: 1836965
- Mageia 9 Mass Rebuild

* Tue Jun 01 2021 ns80 <ns80> 3.5.28-2.mga9
+ Revision: 1729134
- add Ubuntu patches for CVE-2021-3500 and CVE-2021-3249[0-3] (mga#29000)

* Thu Dec 03 2020 luigiwalser <luigiwalser> 3.5.28-1.mga8
+ Revision: 1652030
- call autoreconf to generate configure
- 3.5.28
- remove upstreamed patches

* Tue Feb 18 2020 umeabot <umeabot> 3.5.27-7.mga8
+ Revision: 1538615
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Nov 25 2019 ns80 <ns80> 3.5.27-6.mga8
+ Revision: 1462716
- add patches for CVE-2019-1514[2-5] and CVE-2019-18804 (mga#25730)

* Sun Sep 23 2018 umeabot <umeabot> 3.5.27-5.mga7
+ Revision: 1297457
- Mageia 7 Mass Rebuild

* Thu Sep 28 2017 cjw <cjw> 3.5.27-4.mga7
+ Revision: 1161048
- do not use the --enable-debug configure option for the build

* Sat Jul 29 2017 akien <akien> 3.5.27-3.mga7
+ Revision: 1132562
- BR libjpeg and libtiff-4 for additional features

* Thu Feb 11 2016 umeabot <umeabot> 3.5.27-2.mga6
+ Revision: 953787
- Mageia 6 Mass Rebuild
+ shlomif <shlomif>
- Fix grammar and trailing whitespace.
- Debian has a new 3.5.27.1 release, but I cannot find it anywhere on the djvu
  site so not packaging it.

* Sun Jun 21 2015 luigiwalser <luigiwalser> 3.5.27-1.mga6
+ Revision: 837005
- 3.5.27

* Wed Oct 15 2014 umeabot <umeabot> 3.5.25-6.mga5
+ Revision: 743089
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.5.25-5.mga5
+ Revision: 678761
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 3.5.25-4.mga4
+ Revision: 503898
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 3.5.25-3.mga3
+ Revision: 348831
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 26 2012 wally <wally> 3.5.25-2.mga3
+ Revision: 335498
- drop .la files
- clean .spec a bit

* Sun Aug 19 2012 luigiwalser <luigiwalser> 3.5.25-1.mga3
+ Revision: 282300
- 3.5.25

* Thu Sep 08 2011 tv <tv> 3.5.24-1.mga2
+ Revision: 141506
- new release

* Mon Jan 17 2011 pterjan <pterjan> 3.5.23-1.mga1
+ Revision: 21245
- Update to 3.5.23
- Disable djview3/djvulibre-browser-plugin, new qt4 replacement exist
- imported package djvulibre


* Mon Dec 20 2010 Funda Wang <fwang@mandriva.org> 3.5.22-4mdv2011.0
+ Revision: 623257
- fix link
- fix link
- update file list

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 3.5.22-3mdv2010.1
+ Revision: 488747
- rebuilt against libjpeg v8

* Sat Aug 15 2009 Oden Eriksson <oeriksson@mandriva.com> 3.5.22-2mdv2010.0
+ Revision: 416612
- rebuilt against libjpeg v7

* Thu Jun 25 2009 Frederik Himpe <fhimpe@mandriva.org> 3.5.22-1mdv2010.0
+ Revision: 389198
- Update to new version 3.5.22

* Mon Feb 09 2009 Helio Chissini de Castro <helio@mandriva.com> 3.5.21-3mdv2009.1
+ Revision: 338866
- Get rid of kde3 dependency

* Sun Sep 07 2008 Frederik Himpe <fhimpe@mandriva.org> 3.5.21-1mdv2009.0
+ Revision: 282351
- Update to new version (new major)
- Fix Source0 to use gz tarball
- Better URL

* Fri Jun 20 2008 Pixel <pixel@mandriva.com> 3.5.20-5mdv2009.0
+ Revision: 227421
- rebuild for fixed %%update_icon_cache/%%clean_icon_cache/%%post_install_gconf_schemas
- rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Mon Jun 16 2008 Thierry Vignaud <tv@mandriva.org> 3.5.20-4mdv2009.0
+ Revision: 220637
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - fixes bug #40569
    - enable browser plugin

* Tue Mar 11 2008 Erwan Velu <erwan@mandriva.org> 3.5.20-2mdv2008.1
+ Revision: 186732
- Rebuild

* Wed Jan 02 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 3.5.20-1mdv2008.1
+ Revision: 140272
- new version
- new license policy

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Sep 18 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.5.19-3mdv2008.0
+ Revision: 89602
- rebuild

* Fri Aug 17 2007 David Walluck <walluck@mandriva.org> 3.5.19-2mdv2008.0
+ Revision: 64686
- disable browser plugin (obsoleted by djview4)
- fix file conflicts with djview4

* Tue Jul 17 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 3.5.19-1mdv2008.0
+ Revision: 52878
- new version
- new devel library policy
- drop old menu style
- drop X-MandrivaLinux category from desktop file
- add more provides


* Thu Mar 01 2007 Götz Waschk <waschk@mandriva.org> 3.5.18-2mdv2007.0
+ Revision: 130390
- remove libdjvulibre.so from the plugin package
- Import djvulibre

* Sun Feb 04 2007 Götz Waschk <waschk@mandriva.org> 3.5.18-1mdv2007.1
- fix mime, icons and desktop entry
- fix buildrequires
- New version 3.5.18

* Wed Sep 06 2006 Nicolas Lécureuil <neoclust@mandriva.org> 3.5.17-5mdv2007.0
- XDG

* Wed Jun 07 2006 Götz Waschk <waschk@mandriva.org> 3.5.17-4mdv2007.0
- fix buildrequires

* Sun May 28 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.5.17-3mdk
- add BuildRequires: kdelibs-common

* Wed May 24 2006 Götz Waschk <waschk@mandriva.org> 3.5.17-2mdk
- fix devel provides

* Wed May 24 2006 Götz Waschk <waschk@mandriva.org> 3.5.17-1mdk
- update file list
- disable -frepo
- New release 3.5.17

* Fri Mar 03 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.5.16-3mdk
- add BuildRequires: gnome-mime-data

* Tue Nov 22 2005 Laurent MONTEL <lmontel@mandriva.com> 3.5.16-2
- Remove conflict

* Wed Nov 02 2005 David Walluck <walluck@mandriva.org> 3.5.16-1mdk
- 3.5.16
- add menu icons

* Thu Mar 17 2005 David Walluck <walluck@mandrake.com> 3.5.14-4mdk
- fix ldconfig location

* Wed Mar 16 2005 David Walluck <walluck@mandrake.com> 3.5.14-3mdk
- fix summary-ended-with-dot
- fix wrong-script-end-of-line-encoding 
- replace hardcoded paths with the correct macro-based paths

* Wed Mar 16 2005 David Walluck <walluck@mandrake.com> 3.5.14-2mdk
- rebuild to fix unresolved symbols
- use %%configure macro

* Fri Aug 27 2004 Lenny Cartier <lenny@mandrakesoft.com> 3.5.14-1mdk
- 3.5.14

* Fri May 28 2004 Lenny Cartier <lenny@mandrakesoft.com> 3.5.13-2mdk
- browser plugin is back
- add link to mozilla plugin path

* Tue May 25 2004 Lenny Cartier <lenny@mandrakesoft.com> 3.5.13-1mdk
- 3.5.13

* Thu May 13 2004 Lenny Cartier <lenny@mandrakesoft.com> 3.5.12-2mdk
- rebuild
- remove explicit lib dependency

